@@ -340,37 +340,6 @@ class Worker:
     def _enqueue(self, request_id):
         self.queue.send_message(base64.b64encode(request_id.encode()).decode())
 
-    def _read_blob_by_chunks(self, input_blob):
-        blob_data = input_blob.download_blob()
-        last_piece = ""
-        for chunk in blob_data.chunks():
-            lines = [l.strip() for l in chunk.decode().split("\r\n") if len(l.strip()) > 0]
-            lines[0] = last_piece + lines[0]
-            last_piece = lines[-1]
-            segments = []
-            for l in lines[:-1]:
-                l = self._preprocess(l)
-                if len(l) == 0:
-                    continue
-                source = self._preprocess(json.loads(l)[0])
-                target = self._preprocess(json.loads(l)[1])
-                if self.return_only_sources:
-                    segments.append(source)
-                else:
-                    segments.append((source, target))
-            yield segments
-
-        last_piece = self._preprocess(last_piece)
-        if len(last_piece) > 0:
-            source = None
-            try:
-                source = self._preprocess(json.loads(last_piece)[0])
-                target = self._preprocess(json.loads(last_piece)[1])
-            except:
-                pass
-            if source:
-                yield [source, target]
-
     @staticmethod
     def _preprocess(text):
         return text.replace("\xa0", " ").replace("&nbsp;", " ").strip()
@@ -386,21 +355,19 @@ class Worker:
                 l = self._preprocess(l)
                 if len(l) == 0:
                     continue
-                source = self._preprocess(json.loads(l)[0])
-                target = self._preprocess(json.loads(l)[1])
+                source, target = json.loads(l)
                 if self.return_only_source:
-                    yield source
+                    yield self._preprocess(source)
                 else:
-                    yield source, target
+                    yield self._preprocess(source), self._preprocess(target)
 
         last_piece = self._preprocess(last_piece)
         if len(last_piece) > 0:
-            source = self._preprocess(json.loads(last_piece)[0])
-            target = self._preprocess(json.loads(last_piece)[1])
+            source, target = json.loads(last_piece)
             if self.return_only_source:
-                yield source
+                yield self._preprocess(source)
             else:
-                return source, target
+                yield self._preprocess(source), self._preprocess(target)
 
     @staticmethod
     def _generate_request_id(data, guid=None):
